@@ -4,9 +4,9 @@
 /* 
    drvlatex2e.h : This file is part of pstoedit
    Class declaration for a LaTeX2e output driver
-   Contributed by: Scott Pakin <pakin@uiuc.edu>
+   Contributed by: Scott Pakin <scott+ps2ed_AT_pakin.org>
 
-   Copyright (C) 1993 - 2006 Wolfgang Glunz, wglunz34_AT_pstoedit.net
+   Copyright (C) 1993 - 2009 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
