@@ -4,7 +4,7 @@
 
    Copyright (C) 1996,1997 Jens Weber, rz47b7_AT_PostAG.DE
    Copyright (C) 1998 Thorsten Behrens and Bjoern Petersen
-   Copyright (C) 1998 - 2007 Wolfgang Glunz
+   Copyright (C) 1998 - 2009 Wolfgang Glunz
    Copyright (C) 2000 Thorsten Behrens
 
     This program is free software; you can redistribute it and/or modify
@@ -81,7 +81,7 @@ struct PLACEABLEHEADER {
 	WORD checksum;
 };
 
-static const char description[] = "generated by WMF/EMF backend of pstoedit\0input\0\0";
+static const char description[] = "generated by WMF/EMF backend of pstoedit\0input\0\0"; //lint !e840 //usage of nul char in string
 
 
 inline float drvWMF::scale() const
@@ -165,7 +165,8 @@ drvWMF::derivedConstructor(drvWMF):
 constructBase,
 oldColoredPen(NIL),
 oldColoredBrush(NIL),
-enhanced(false)
+enhanced(false),
+outFile(0L)
 {
 	// do some consistency checking
 	if (! ( (sizeof(PLACEABLEHEADER) == PLACEABLESIZE) || (sizeof(PLACEABLEHEADER) == (PLACEABLESIZE+2)) ) ) {
@@ -703,8 +704,8 @@ int drvWMF::fetchFont(const TextInfo & textinfo, short int textHeight, short int
 void drvWMF::drawPoly(POINT * aptlPoints, int *aptlNumPts, polyType type)
 {
 	POINT lastStart = { 0, 0 };
-	bool lastWasMoveTo = FALSE;
-	bool lastWasClosePath = FALSE;
+	bool lastWasMoveTo = false;
+	bool lastWasClosePath = false;
 	unsigned int numOfPolies = 0;
 	unsigned int numOfPts = 0;
 	unsigned int p = 0;
@@ -799,10 +800,10 @@ void drvWMF::drawPoly(POINT * aptlPoints, int *aptlNumPts, polyType type)
 				numOfPts = 0;
 
 				// set flag to remove lone moveto's
-				lastWasMoveTo = TRUE;
+				lastWasMoveTo = true;
 
 				// clear flag to connect filled segments
-				lastWasClosePath = FALSE;
+				lastWasClosePath = true;
 			}
 
 			// save last starting position in case we've to close path
@@ -818,10 +819,10 @@ void drvWMF::drawPoly(POINT * aptlPoints, int *aptlNumPts, polyType type)
 				}
 			} else {
 				// clear flag to remove lone moveto's
-				lastWasMoveTo = FALSE;
+				lastWasMoveTo = false;
 
 				// clear flag to connect filled segments
-				lastWasClosePath = FALSE;
+				lastWasClosePath = false;
 
 				// do nothing, point is already in array
 			}
@@ -835,10 +836,10 @@ void drvWMF::drawPoly(POINT * aptlPoints, int *aptlNumPts, polyType type)
 				}
 			} else {
 				// clear flag to remove lone moveto's
-				lastWasMoveTo = FALSE;
+				lastWasMoveTo = false;
 
 				// set flag to connect filled segments
-				lastWasClosePath = TRUE;
+				lastWasClosePath = true;
 
 				// insert line to startpoint
 				// (overwrite current point - closepath did not inserted points)
@@ -933,21 +934,20 @@ void drvWMF::open_page()
 
 
 void drvWMF::show_path()
-{
-	POINT *aptlPoints = NIL;
-	int *aptlNumPts = NIL;
-
-
+{	
 	// get us twice the number of elements in path,
 	// as maybe every subpath is closed and consists of ONE point!
-	if ((aptlPoints = new POINT[2 * numberOfElementsInPath()]) == NIL) {
+	POINT *aptlPoints = new POINT[2 * numberOfElementsInPath()];
+	if (aptlPoints == 0) {
 		errf << "ERROR: Cannot allocate memory for point-array" << endl;
 		return;
 	}
 	// get us twice the number of elements in path,
 	// as maybe every subpath is closed and consists of ONE point!
-	if ((aptlNumPts = new int[2 * numberOfElementsInPath()]) == NIL) {
+	int *aptlNumPts = new int[2 * numberOfElementsInPath()];
+	if (aptlNumPts == 0) {
 		errf << "ERROR: Cannot allocate memory for pointNum-array" << endl;
+		delete [] aptlPoints;
 		return;
 	}
 	// update pen/brush
@@ -1056,7 +1056,7 @@ void drvWMF::show_text(const TextInfo & textinfo)
 		TextOut(metaDC, x1, y1, textinfo.thetext.value(), textLen);
 	} else {
 		// we are not running Windows - so we need an emulation - see note below
-		const long textdistance = (long) sqrt((double)((x1-x2)*(x1-x2) + (y1-y2)*(y1-y2)));
+		const long textdistance = (long) pythagoras((double)(x1-x2), (double)(y1-y2));
 		const int letterspace = (textLen > 1) ? (textdistance / (textLen-1)) : 0 ;
 		// if there is just one char in the text, then the inter letter spacing is 0 anyway
 		int * pxDistance = new int[textLen];
