@@ -2,7 +2,7 @@
    dynload.h : This file is part of pstoedit
    declarations for dynamic loading of drivers
 
-   Copyright (C) 1993 - 2006 Wolfgang Glunz, wglunz34_AT_pstoedit.net
+   Copyright (C) 1993 - 2009 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ public:
 	fptr getSymbol(const char * name, int check = 1) const;
 	int  knownSymbol(const char * name) const;
 	int  valid() const { return handle != 0; }
-	void * gethandle() const { return handle; }
+	const void * gethandle() const { return handle; }
 private:
 	const char * libname;
 	void* handle;	
