@@ -4,7 +4,7 @@
    pstoedll.h : This file describes the interface to query information about
    the drivers available via pstoedit and to call pstoedit via the dll interface
   
-   Copyright (C) 1998 - 2006 Wolfgang Glunz, wglunz34_AT_pstoedit.net
+   Copyright (C) 1998 - 2009 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,9 +34,9 @@ struct DriverDescription_S {
 	const char *	additionalInfo;
 	int		backendSupportsSubPathes;
 	int		backendSupportsCurveto;
-	int 	backendSupportsMerging; 
-	int 	backendSupportsText;
-	int 	backendSupportsImages;
+	int 		backendSupportsMerging; 
+	int 		backendSupportsText;
+	int 		backendSupportsImages;
 	int		backendSupportsMultiplePages;
 };
 
@@ -44,7 +44,7 @@ static const unsigned int pstoeditdllversion = 301;
 /* 301: added the clearPstoeditDriverInfo function to avoid problems with using different mallac/free in server and client. */
 
 typedef int  (pstoedit_checkversion_func)  (unsigned int callersversion );
-typedef void (setPstoeditsetDLLUsage_func) (int useDLL_p); // need to use int instead of bool because of C mode
+typedef void (setPstoeditsetDLLUsage_func) (int useDLL_p); /* need to use int instead of bool because of C mode */
 
 typedef int  (pstoedit_plainC_func) (int argc,const char * const argv[],const char * const psinterpreter );
 /* psinterpreter can be set to 0, in which case pstoedit tries to locate one on his own. */
